@@ -11,11 +11,11 @@ class RebuildWikiConfigs:
     def run(self):
         from torque import models
 
-        for config in models.WikiConfig.objects.filter(cache_dirty=True).all():
+        for config in models.WikiConfig.objects.filter(search_cache_dirty=True).all():
             # We do this outside of the transaction, because if someone comes
             # along and dirties it again while we're rebuilding, we want to
             # rebuild it after we're done rebuilding it.
-            config.cache_dirty = False
+            config.search_cache_dirty = False
             config.save()
             print(
                 "Rebuilding search index for %s: %s"
@@ -23,12 +23,6 @@ class RebuildWikiConfigs:
             )
             with transaction.atomic():
                 config.rebuild_search_index()
-            print(
-                "Rebuilding template index for %s: %s"
-                % (config.wiki.wiki_key, config.group)
-            )
-            with transaction.atomic():
-                config.rebuild_template_cache()
 
 
 class RebuildTOCs:
@@ -59,6 +53,10 @@ class RebuildSearchCacheDocuments:
     def run(self):
         from torque import models
 
+        num = models.SearchCacheDocument.objects.filter(dirty=True).count()
+        if num > 0:
+            print("Rebuilding %s search cache documents" % num)
+
         for cache_document in models.SearchCacheDocument.objects.filter(dirty=True):
             collection = cache_document.document.collection
             for config in collection.configs.all():
@@ -71,6 +69,40 @@ class RebuildSearchCacheDocuments:
                 )
 
 
+class RebuildTemplateCacheDocuments:
+    def run(self):
+        from torque import models
+
+        for template in models.Template.objects.filter(dirty=True).all():
+            template.dirty = False
+            template.save()
+
+            # Right now, CSV Templates affect the template cache, and TOC templates
+            # affect the ToC cache.  Others we just pass on.
+            #
+            # We mark it as clean even if it's another type, just so things are clean if
+            # we end up adding other template types later
+            if template.type == "CSV":
+                for config in template.wiki.configs.all():
+                    print(
+                        "Rebuilding template %s (%s) for %s: %s"
+                        % (
+                            template.name,
+                            template.type,
+                            config.wiki.wiki_key,
+                            config.group,
+                        )
+                    )
+                    with transaction.atomic():
+                        config.rebuild_template_cache(template)
+            elif template.type == "TOC":
+                models.TableOfContentsCache.objects.filter(
+                    toc__in=template.collection.tables_of_contents.all()
+                ).update(dirty=True)
+            else:
+                pass
+
+
 class CacheRebuilder(Process):
     def __init__(self):
         super().__init__()
@@ -81,6 +113,7 @@ class CacheRebuilder(Process):
 
         while True:
             try:
+                RebuildTemplateCacheDocuments().run()
                 RebuildWikiConfigs().run()
                 RebuildTOCs().run()
                 RebuildSearchCacheDocuments().run()
