@@ -81,6 +81,7 @@ class Collection(models.Model):
                 collection_values[value.document][value.field] = value
 
         collection.fields.update(attached=False)
+        collection.documents.update(attached=False)
 
         for document_number, document_in in enumerate(data):
             if document_number == 0:
@@ -98,6 +99,7 @@ class Collection(models.Model):
                 collection=collection,
                 key=document_in[collection.key_field],
             )
+            db_document.attached = True
             db_document.save()
             documents.append(db_document)
             for field_name, value_value in document_in.items():
@@ -255,6 +257,14 @@ class Document(models.Model):
     key = models.TextField()
     wiki_config = models.ManyToManyField(WikiConfig, related_name="valid_ids")
 
+    # Attached here represents documents that are actually attached to a collection.
+    #
+    # When uploading a collection, if documents have been dropped off, then they are
+    # no longer actively attached.  Instead of just removing them right away, and
+    # losing any Value or ValueEdits associated, we just mark them as unattached,
+    # and then we can later clean them up if we want.
+    attached = models.BooleanField(default=True)
+
     def to_dict(self, config):
         new_document = {"key": self.key}
         valid_fields = config.valid_fields.all()
@@ -320,6 +330,14 @@ class Value(models.Model):
             else:
                 return ""
 
+    class Meta:
+        constraints = [
+            # useful for making sure we don't accidentally get duplicate values
+            models.UniqueConstraint(
+                fields=["field", "document"], name="unique_value_for_field_document"
+            ),
+        ]
+
 
 class ValueEdit(models.Model):
     value = models.ForeignKey(Value, on_delete=models.CASCADE, related_name="edits")
