@@ -48,6 +48,9 @@ class CsvFieldProcessor:
     def process_value(self, value):
         pass
 
+    def default_value(self, field_name):
+        return [""] * len(self.field_names(field_name))
+
 
 ## A factory method for getting a jinja environment
 def get_jinja_env():
@@ -57,6 +60,10 @@ def get_jinja_env():
             enabled_extensions + settings.TORQUE_ENABLED_JINJA_EXTENSIONS
         )
 
-    return Environment(
-        extensions=enabled_extensions,
-    )
+    env = Environment(extensions=enabled_extensions)
+
+    if getattr(settings, "TORQUE_JINJA_GLOBALS", False):
+        for (key, value) in settings.TORQUE_JINJA_GLOBALS.items():
+            env.globals[key] = value
+
+    return env
