@@ -218,11 +218,17 @@ def edit_record(collection_name, key, group, wiki, field, new_value):
             to_save = new_value
         else:
             to_save = value.to_python()
+
+            inner_save = to_save
             for idx in range(1, len(levels)):
+                level = levels[idx]
+                if isinstance(inner_save, list):
+                    level = int(level)
+
                 if idx + 1 == len(levels):
-                    to_save[levels[idx]] = new_value
+                    inner_save[level] = new_value
                 else:
-                    to_save = to_save[levels[idx]]
+                    inner_save = inner_save[level]
 
         value.latest = json.dumps(to_save)
         value.save()
@@ -250,6 +256,19 @@ def edit_record(collection_name, key, group, wiki, field, new_value):
     collection.save()
 
 
+@csrf_exempt
+@require_http_methods(["POST"])
+def parse_for_edit(request):
+    post_fields = json.loads(request.body)
+
+    if getattr(settings, "TORQUE_EDIT_PROCESSOR", False):
+        return JsonResponse(
+            {"data": settings.TORQUE_EDIT_PROCESSOR(post_fields["data"])}
+        )
+    else:
+        return JsonResponse({"data": post_fields["data"]})
+
+
 def get_collections(request, fmt):
     collection_names = [x for x in request.GET["collection_names"].split(",") if x]
 
@@ -412,6 +431,9 @@ def field(request, collection_name, key, field, fmt):
 
         value = document
         for level in field.split("||"):
+            if isinstance(value, list):
+                level = int(level)
+
             value = value[level]
 
         return JsonResponse(value, safe=False)
@@ -810,16 +832,22 @@ def get_csv(request, name, fmt):
                 ).prefetch_related("field")
             }
             for field_name in valid_field_names:
-                if field_name in values_by_field and field_name in getattr(
+                python_value = None
+                if field_name in values_by_field:
+                    python_value = values_by_field[field_name].to_python()
+
+                if python_value and field_name in getattr(
                     settings, "TORQUE_CSV_PROCESSORS", {}
                 ):
                     row.extend(
                         settings.TORQUE_CSV_PROCESSORS[field_name].process_value(
-                            values_by_field[field_name].to_python()
+                            python_value
                         )
                     )
-                elif field_name in values_by_field:
-                    row.append(values_by_field[field_name].to_python())
+                elif field_name in getattr(settings, "TORQUE_CSV_PROCESSORS", {}):
+                    settings.TORQUE_CSV_PROCESSORS[field_name].default_value(field_name)
+                elif python_value:
+                    row.append(python_value)
                 else:
                     row.append("")
             writer.writerow(row)
